@@ -1,7 +1,7 @@
 drake_context("lazy")
 
 test_with_dir("no overt errors lazy load for the debug example", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_on_cran() # CRAN gets essential tests only (check time limits).
   config <- dbug()
   config$verbose <- FALSE
   config$settings$lazy_load <- TRUE
@@ -37,7 +37,7 @@ test_with_dir("no overt errors lazy load for the debug example", {
 })
 
 test_with_dir("lazy loading is actually lazy", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_on_cran() # CRAN gets essential tests only (check time limits).
   lazily_loaded <- c("nextone", "yourinput")
   eagerly_loaded <- "combined"
   config <- dbug()
@@ -68,7 +68,7 @@ test_with_dir("lazy loading is actually lazy", {
 })
 
 test_with_dir("active bindings", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_on_cran() # CRAN gets essential tests only (check time limits).
   skip_if_not_installed("bindr")
   config <- dbug()
   if (identical(globalenv(), config$envir)) {
